pub async fn create_from_json(
client: &impl RequestRunner,
trigger_req: Value,
) -> Result<Response<Trigger>>Expand description
Create a new trigger from JSON definition.
We intentionally don’t accept Trigger here since API is designed to
be more relaxed than the required fields in Trigger model. If we
accepted Trigger as input, the trigger defaults will be set on
the client side and not server side. To want to make it easy to
change those defaults on the server side without having to release a
new client version.